@@ -11,6 +11,7 @@
 #define COMICMODEL_H
 
 #include <QAbstractTableModel>
+#include <QBitArray>
 
 #include "engine/comic.h"
 
@@ -19,7 +20,13 @@ class ComicModel : public QAbstractTableModel
     Q_OBJECT
 
 public:
-    ComicModel(ComicEngine *engine, const QStringList &usedComics, QObject *parent = nullptr);
+    enum Roles {
+        ComicPluginRole = Qt::UserRole,
+        ComicEnabledRole,
+        ComicHighlightRole
+    };
+
+    ComicModel(ComicEngine *engine, const QStringList &enabledProviders, QObject *parent = nullptr);
 
     QHash<int, QByteArray> roleNames() const override;
 
@@ -27,12 +34,19 @@ public:
     int columnCount(const QModelIndex &index = QModelIndex()) const override;
     QVariant data(const QModelIndex &index, int role = Qt::CheckStateRole) const override;
     Qt::ItemFlags flags(const QModelIndex &index) const override;
+    bool setData(const QModelIndex &index, const QVariant &value, int role = Qt::EditRole) override;
+    void setEnabledProviders(const QStringList &enabledProviders);
+    void setHighlight(const QModelIndex &index, bool highlight);
 
     void load();
+    Q_INVOKABLE QStringList checkedProviders();
 
 private:
     QList<ComicProviderInfo> mComics;
-    QStringList mUsedComics;
+    QBitArray mChecked;
+    QBitArray mEnabled;
+    QBitArray mHighlighted;
+    QStringList mEnabledProviders;
     ComicEngine *mEngine;
 };
 
