@@ -26,6 +26,7 @@
 ComicEngine::ComicEngine(QObject *parent)
     : QObject(parent)
     , mEmptySuffix(false)
+    , mIsCheckingForUpdates(false)
 {
     QNetworkInformation::instance()->loadBackendByFeatures(QNetworkInformation::Feature::Reachability);
     loadProviders();
@@ -52,6 +53,9 @@ QList<ComicProviderInfo> ComicEngine::loadProviders()
         mProviders << comic.pluginId();
         providers << data;
     }
+    std::sort(providers.begin(), providers.end(), [](ComicProviderInfo a, ComicProviderInfo b) {
+        return QString::localeAwareCompare(a.name, b.name) < 1;
+    });
     return providers;
 }
 
@@ -60,6 +64,16 @@ void ComicEngine::setMaxComicLimit(int maxComicLimit)
     CachedProvider::setMaxComicLimit(maxComicLimit);
 }
 
+void ComicEngine::setIsCheckingForUpdates(bool isCheckingForUpdates)
+{
+    mIsCheckingForUpdates = isCheckingForUpdates;
+}
+
+bool ComicEngine::isCheckingForUpdates()
+{
+    return mIsCheckingForUpdates;
+}
+
 bool ComicEngine::requestSource(const QString &identifier)
 {
     if (m_jobs.contains(identifier)) {
@@ -68,9 +82,14 @@ bool ComicEngine::requestSource(const QString &identifier)
 
     const QStringList parts = identifier.split(QLatin1Char(':'), Qt::KeepEmptyParts);
 
+    bool isCurrentComic = parts[1].isEmpty();
+
     // check whether it is cached, make sure second part present
-    if (parts.count() > 1 && (CachedProvider::isCached(identifier) || !isOnline())) {
+    bool lookInCache = parts.count() > 1 && !(isCurrentComic && mIsCheckingForUpdates) && CachedProvider::isCached(identifier);
+
+    if (lookInCache || !isOnline()) {
         ComicProvider *provider = new CachedProvider(this, KPluginMetaData{}, IdentifierType::StringIdentifier, identifier);
+        provider->setIsCurrent(isCurrentComic);
         m_jobs[identifier] = provider;
         connect(provider, &ComicProvider::finished, this, &ComicEngine::finished);
         connect(provider, &ComicProvider::error, this, &ComicEngine::error);
@@ -80,7 +99,7 @@ bool ComicEngine::requestSource(const QString &identifier)
     // ... start a new query otherwise
     if (parts.count() < 2) {
         Q_EMIT requestFinished(ComicMetaData{.error = true});
-        qWarning() << "Less than two arguments specified.";
+        qCWarning(PLASMA_COMIC) << "Less than two arguments specified.";
         return false;
     }
     if (!mProviders.contains(parts[0])) {
@@ -88,7 +107,7 @@ bool ComicEngine::requestSource(const QString &identifier)
         loadProviders();
         if (!mProviders.contains(parts[0])) {
             Q_EMIT requestFinished(ComicMetaData{.error = true});
-            qWarning() << identifier << "comic plugin does not seem to be installed.";
+            qCWarning(PLASMA_COMIC) << identifier << "comic plugin does not seem to be installed.";
             return false;
         }
     }
@@ -109,8 +128,6 @@ bool ComicEngine::requestSource(const QString &identifier)
 
     KPackage::Package pkg = KPackage::PackageLoader::self()->loadPackage(QStringLiteral("Plasma/Comic"), parts[0]);
 
-    bool isCurrentComic = parts[1].isEmpty();
-
     ComicProvider *provider = nullptr;
 
     QVariant data;
@@ -158,9 +175,19 @@ void ComicEngine::finished(ComicProvider *provider)
         mIdentifierError.clear();
     }
 
+    if (provider->isCurrent()) {
+        data.lastCachedStripIdentifier = provider->identifier().mid(provider->identifier().indexOf(QLatin1Char(':')) + 1);
+    } else {
+        data.lastCachedStripIdentifier = lastCachedIdentifier(provider->identifier());
+    }
+
     // store in cache if it's not the response of a CachedProvider,
     if (!provider->inherits("CachedProvider") && !provider->image().isNull()) {
         CachedProvider::storeInCache(provider->identifier(), provider->image(), data);
+        if (provider->isCurrent()) {
+            QString currentIdentifier = provider->identifier().left(provider->identifier().indexOf(QLatin1Char(':')) + 1);
+            CachedProvider::storeInCache(currentIdentifier, provider->image(), data);
+        }
     }
     provider->deleteLater();
 
@@ -176,18 +203,18 @@ void ComicEngine::error(ComicProvider *provider)
     QString identifier(provider->identifier());
     mIdentifierError = identifier;
 
-    qWarning() << identifier << "plugging reported an error.";
+    qCWarning(PLASMA_COMIC) << identifier << "plugin reported an error.";
 
     ComicMetaData data = metaDataFromProvider(provider);
     data.error = true;
 
     // if there was an error loading the last cached comic strip, do not return its id anymore
     const QString lastCachedId = lastCachedIdentifier(identifier);
-    if (lastCachedId != provider->identifier().mid(provider->identifier().indexOf(QLatin1Char(':')) + 1)) {
+    bool hasPreviousIdentifier = data.previousIdentifier.length() > 0;
+    if (!hasPreviousIdentifier && lastCachedId != provider->identifier().mid(provider->identifier().indexOf(QLatin1Char(':')) + 1)) {
         // sets the previousIdentifier to the identifier of a strip that has been cached before
         data.previousIdentifier = lastCachedId;
     }
-    data.nextIdentifier = QString();
 
     const QString key = m_jobs.key(provider);
     if (!key.isEmpty()) {
